!$Id: chem_mod.F90 104 2008-12-23 10:28:51Z acosce $
!! =========================================================================
!! INCA - INteraction with Chemistry and Aerosols
!! 
!! Copyright Laboratoire des Sciences du Climat et de l'Environnement (LSCE)
!! 	     Unite mixte CEA-CNRS-UVSQ
!! 
!! Contributors to this INCA subroutine:
!! 
!! Anne Cozic, LSCE, anne.cozic@cea.fr
!!
!! This software is a computer program whose purpose is to simulate the 
!! atmospheric gas phase and aerosol composition. The model is designed to be
!! used within a transport model or a general circulation model. This version 
!! of INCA was designed to be coupled to the LMDz GCM. LMDz-INCA accounts
!! for emissions, transport (resolved and sub-grid scale), photochemical 
!! transformations, and scavenging (dry deposition and washout) of chemical 
!! species and aerosols interactively in the GCM. Several versions of the INCA
!! model are currently used depending on the envisaged applications with the 
!! chemistry-climate model. 
!! 
!! This software is governed by the CeCILL  license under French law and
!! abiding by the rules of distribution of free software.  You can  use, 
!! modify and/ or redistribute the software under the terms of the CeCILL
!! license as circulated by CEA, CNRS and INRIA at the following URL
!! "http://www.cecill.info". 
!! 
!! As a counterpart to the access to the source code and  rights to copy,
!! modify and redistribute granted by the license, users are provided only
!! with a limited warranty  and the software's author,  the holder of the
!! economic rights,  and the successive licensors  have only  limited
!! liability. 
!! 
!! In this respect, the user's attention is drawn to the risks associated
!! with loading,  using,  modifying and/or developing or reproducing the
!! software by the user in light of its specific status of free software,
!! that may mean  that it is complicated to manipulate,  and  that  also
!! therefore means  that it is reserved for developers  and  experienced
!! professionals having in-depth computer knowledge. Users are therefore
!! encouraged to load and test the software's suitability as regards their
!! requirements in conditions enabling the security of their systems and/or 
!! data to be ensured and,  more generally, to use and operate it in the 
!! same conditions as regards security. 
!! 
!! The fact that you are presently reading this means that you have had
!! knowledge of the CeCILL license and that you accept its terms.
!! =========================================================================

#include <inca_define.h>

MODULE PRINT_INCA

  IMPLICIT NONE
  INTEGER, SAVE :: lunout
!$OMP THREADPRIVATE(lunout)
  INTEGER, SAVE :: outxml
!$OMP THREADPRIVATE(outxml) 

CONTAINS

  SUBROUTINE INIT_PRINT_INCA()

    USE MOD_INCA_MPI_DATA, ONLY : is_ok_mpi, mpi_rank
    USE MOD_INCA_OMP_DATA, ONLY : is_ok_omp, omp_rank
    USE mod_inca_mpi_data, ONLY : is_mpi_root

    IMPLICIT NONE
    CHARACTER(len=8) :: namefile
    INTEGER :: ierr2
    CHARACTER(len=255) :: fileout
    CHARACTER(len=4)  :: num_mpi
    CHARACTER(len=4)  :: num_omp
    INTEGER,PARAMETER :: base_lunout=350
    INTEGER           :: ierr


    namefile='inca.out'
   IF (is_ok_mpi) THEN
       WRITE(num_mpi,'(I4.4)') mpi_rank
    ENDIF
    
    IF (is_ok_omp) THEN
       WRITE(num_omp,'(I4.4)') omp_rank
    ENDIF

    IF (is_ok_mpi .AND. is_ok_omp) THEN
       fileout=TRIM(namefile)//'_'//num_mpi//'.'//num_omp
       lunout=base_lunout+omp_rank
    ELSE IF (is_ok_mpi .AND. (.NOT. is_ok_omp)) THEN
       fileout=TRIM(namefile)//'_'//num_mpi
       lunout=base_lunout
    ELSE IF ((.NOT. is_ok_mpi) .AND. is_ok_omp) THEN
       fileout=TRIM(namefile)//'_'//num_omp
       lunout=base_lunout+omp_rank
    ELSE
       fileout=TRIM(namefile)
       lunout=base_lunout
    ENDIF
!    open(UNIT=lunout,file=fileout, action='write',status='unknown', form='formatted', iostat=ierr2) 
!    IF (ierr2 /= 0) THEN
!       stop 'print_inca'
!    endif
    lunout=6

    
!$OMP MASTER
    IF (is_mpi_root) THEN
       outxml=base_lunout*10
       open(UNIT=outxml,file='inca_IDxml.out', action='write',status='unknown', form='formatted', iostat=ierr2) 
       IF (ierr2 /= 0) THEN
          stop 'print_inca xml'
       endif
    endif
    
!$OMP END MASTER


  END SUBROUTINE INIT_PRINT_INCA
END MODULE PRINT_INCA
